==> fgx_umeng_push-2.0.0.tar.gz: ios/Classes/UmengPushSdkPlugin.m <==
#import "UmengPushSdkPlugin.h"

#import <UMPush/UMessage.h>
#include <arpa/inet.h>

@interface UMengflutterpluginForPush : NSObject
@end
@implementation UMengflutterpluginForPush : NSObject

+ (BOOL)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
	BOOL resultCode = YES;
	if ([@"register" isEqualToString:call.method]) {
//		////设置注册的参数，如果不需要自定义的特殊功能可以直接在registerForRemoteNotificationsWithLaunchOptions的Entity传入一个nil.
//		UMessageRegisterEntity * entity = [[UMessageRegisterEntity alloc] init];
//		//type是对推送的几个参数的选择，可以选择一个或者多个。默认是三个全部打开，即：声音，弹窗，角标
//		entity.types = UMessageAuthorizationOptionBadge|UMessageAuthorizationOptionAlert|UMessageAuthorizationOptionSound;
		//友盟推送的注册方法
		[UMessage registerForRemoteNotificationsWithLaunchOptions:nil Entity:nil completionHandler:^(BOOL granted, NSError * _Nullable error) {
		         if (granted) {
				 //点击允许
				 //result(@(YES));
			 } else {
				 //点击不允许
				 //result(@(NO));
			 }
		 }];
	}
	else if([@"getDeviceToken" isEqualToString:call.method]) {
		NSData* deviceToken = [[NSUserDefaults standardUserDefaults] objectForKey:@"kUMessageUserDefaultKeyForDeviceToken"];
		NSString* resultStr = NULL;
		if ([deviceToken isKindOfClass:[NSData class]]) {
			const unsigned *tokenBytes = (const unsigned *)[deviceToken bytes];
			NSString *hexToken = [NSString stringWithFormat:@"%08x%08x%08x%08x%08x%08x%08x%08x",
			                      ntohl(tokenBytes[0]), ntohl(tokenBytes[1]), ntohl(tokenBytes[2]),
			                      ntohl(tokenBytes[3]), ntohl(tokenBytes[4]), ntohl(tokenBytes[5]),
			                      ntohl(tokenBytes[6]), ntohl(tokenBytes[7])];
			resultStr = hexToken;
		}
		else{
			resultStr = @"";
		}
		result(resultStr);

	}
	else if([@"addAlias" isEqualToString:call.method]) {
		NSDictionary* arguments = (NSDictionary *)call.arguments;
		NSString* name = [arguments valueForKey:@"alias"];
		NSString* type = [arguments valueForKey:@"type"];
		[UMessage addAlias:name type:type response:^(id _Nonnull responseObject, NSError * _Nonnull error) {
		         //NSMutableDictionary* resultDic = [[NSMutableDictionary alloc] init];
		         NSNumber* resultNum = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 //[resultDic setValue:error.description forKey:@"error"];
				 resultNum = [NSNumber numberWithBool:NO];
			 }
		         else{
				 NSLog(@"responseObject:%@",responseObject);
//                if ([responseObject isKindOfClass:[NSDictionary class]]) {
//                    [resultDic addEntriesFromDictionary:responseObject];
//                }
				 resultNum = [NSNumber numberWithBool:YES];
			 }
		         //NSString* resultStr =  jsonStringForPlugin(resultDic);
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultNum);
					});
		 }];

	}
	else if([@"setAlias" isEqualToString:call.method]) {
		NSDictionary* arguments = (NSDictionary *)call.arguments;
		NSString* name = [arguments valueForKey:@"alias"];
		NSString* type = [arguments valueForKey:@"type"];
		[UMessage setAlias:name type:type response:^(id _Nullable responseObject, NSError * _Nullable error) {
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(!error ? @(true): @(false));
					});
		 }];
	}
	else if([@"removeAlias" isEqualToString:call.method]) {
		NSDictionary* arguments = (NSDictionary *)call.arguments;
		NSString* name = [arguments valueForKey:@"alias"];
		NSString* type = [arguments valueForKey:@"type"];
		[UMessage removeAlias:name type:type response:^(id _Nonnull responseObject, NSError * _Nonnull error) {
		         NSNumber* resultNum = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 resultNum = [NSNumber numberWithBool:NO];
			 }
		         else{
				 NSLog(@"responseObject:%@",responseObject);
				 resultNum = [NSNumber numberWithBool:YES];
			 }
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultNum);
					});
		 }];
	}
	else if([@"addTag" isEqualToString:call.method]) {
		NSArray* arguments = (NSArray *)call.arguments;
		[UMessage addTags:arguments response:^(id _Nonnull responseObject, NSInteger remain, NSError * _Nonnull error) {
		         NSNumber* resultNum = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 resultNum = [NSNumber numberWithBool:NO];
			 }
		         else{
				 NSLog(@"responseObject:%@",responseObject);
				 resultNum = [NSNumber numberWithBool:YES];
			 }
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultNum);
					});
		 }];
	}
	else if([@"removeTag" isEqualToString:call.method]) {
		NSArray* arguments = (NSArray *)call.arguments;
		[UMessage deleteTags:arguments response:^(id _Nonnull responseObject, NSInteger remain, NSError * _Nonnull error) {
		         NSNumber* resultNum = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 resultNum = [NSNumber numberWithBool:NO];
			 }
		         else{
				 NSLog(@"responseObject:%@",responseObject);
				 resultNum = [NSNumber numberWithBool:YES];
			 }
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultNum);
					});
		 }];
	}
	else if([@"getTags" isEqualToString:call.method]) {
//        NSArray* arguments = (NSArray *)call.arguments;
		[UMessage getTags:^(NSSet * _Nonnull responseTags, NSInteger remain, NSError * _Nonnull error) {
		         NSArray<NSString*>* resultArr = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 resultArr = [NSArray array];
			 }
		         else{
				 NSLog(@"responseTags:%@",responseTags);
				 NSArray* tempResultArr = [responseTags allObjects];
				 resultArr = [[NSArray alloc] initWithArray:tempResultArr];
			 }
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultArr);
					});
		 }];
	}
	else if([@"log_enable" isEqualToString:call.method]) {
		NSLog(@"log_enable is a empty function。see [UMConfigure setLogEnabled:YES]");
	}
	else if([@"enable" isEqualToString:call.method]) {
		NSLog(@"push enable is a empty function");
	}
	else{
		resultCode = NO;
	}

	return resultCode;
}
@end

@interface UmengPushSdkPlugin () <UNUserNotificationCenterDelegate>
@property(nonatomic, strong) FlutterMethodChannel *channel;
@end

@implementation UmengPushSdkPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
	FlutterMethodChannel* channel = [FlutterMethodChannel
	                                 methodChannelWithName:@"u-push"
	                                 binaryMessenger:[registrar messenger]];
	UmengPushSdkPlugin* instance = [[UmengPushSdkPlugin alloc] init];
	instance.channel = channel;
	UNUserNotificationCenter.currentNotificationCenter.delegate = instance;
	[registrar addApplicationDelegate:instance];
	[registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
	BOOL resultCode = [UMengflutterpluginForPush handleMethodCall:call result:result];
	if (resultCode) return;
	result(FlutterMethodNotImplemented);
}

#pragma mark - UIApplicationDelegate
- (void)application:(UIApplication *)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken {
	[UMessage registerDeviceToken:deviceToken];
//    NSString *token = [[deviceToken description] stringByTrimmingCharactersInSet:[NSCharacterSet characterSetWithCharactersInString:@"<>"]];
//    token = [token stringByReplacingOccurrencesOfString:@" " withString:@""];

	NSString *token = [self fetchDeviceToken:deviceToken];
	[self.channel invokeMethod:@"onToken" arguments:token];
}

- (NSString *)fetchDeviceToken:(NSData *)deviceToken {
	NSUInteger len = deviceToken.length;
	if (len == 0) {
		return nil;
	}
	const unsigned char *buffer = deviceToken.bytes;
	NSMutableString *hexString  = [NSMutableString stringWithCapacity:(len * 2)];
	for (int i = 0; i < len; ++i) {
		[hexString appendFormat:@"%02x", buffer[i]];
	}
	return [hexString copy];
}

#pragma mark - UNUserNotificationCenterDelegate
- (void)userNotificationCenter:(UNUserNotificationCenter *)center willPresentNotification:(UNNotification *)notification withCompletionHandler:(void (^)(UNNotificationPresentationOptions))completionHandler {
	NSError *err;
	NSData *jsonData = [NSJSONSerialization dataWithJSONObject:notification.request.content.userInfo options:0 error:&err];
	if (!err) {
		NSString *message = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
		[self.channel invokeMethod:@"onMessage" arguments:message];
	}
	if (completionHandler) {
		completionHandler(UNNotificationPresentationOptionBadge | UNNotificationPresentationOptionSound | UNNotificationPresentationOptionAlert);
	}
}

- (void)userNotificationCenter:(UNUserNotificationCenter *)center didReceiveNotificationResponse:(UNNotificationResponse *)response withCompletionHandler:(void (^)(void))completionHandler {
	NSError *err;
	NSData *jsonData = [NSJSONSerialization dataWithJSONObject:response.notification.request.identifier options:0 error:&err];
	if (!err) {
		NSString *message = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
		[self.channel invokeMethod:@"onMessage" arguments:message];
	}
	if (completionHandler) {
		completionHandler();
	}
}


@end

==> fgx_umeng_push-2.0.1.tar.gz: ios/Classes/UmengPushSdkPlugin.m <==
#import "UmengPushSdkPlugin.h"

#import <UMPush/UMessage.h>
#include <arpa/inet.h>

@interface UMengflutterpluginForPush : NSObject
@end
@implementation UMengflutterpluginForPush : NSObject

+ (BOOL)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
	BOOL resultCode = YES;
	if ([@"register" isEqualToString:call.method]) {
//		////设置注册的参数，如果不需要自定义的特殊功能可以直接在registerForRemoteNotificationsWithLaunchOptions的Entity传入一个nil.
//		UMessageRegisterEntity * entity = [[UMessageRegisterEntity alloc] init];
//		//type是对推送的几个参数的选择，可以选择一个或者多个。默认是三个全部打开，即：声音，弹窗，角标
//		entity.types = UMessageAuthorizationOptionBadge|UMessageAuthorizationOptionAlert|UMessageAuthorizationOptionSound;
		//友盟推送的注册方法
		[UMessage registerForRemoteNotificationsWithLaunchOptions:nil Entity:nil completionHandler:^(BOOL granted, NSError * _Nullable error) {
		         if (granted) {
				 //点击允许
				 //result(@(YES));
			 } else {
				 //点击不允许
				 //result(@(NO));
			 }
		 }];
	}
	else if([@"getDeviceToken" isEqualToString:call.method]) {
		NSData* deviceToken = [[NSUserDefaults standardUserDefaults] objectForKey:@"kUMessageUserDefaultKeyForDeviceToken"];
		NSString* resultStr = NULL;
		if ([deviceToken isKindOfClass:[NSData class]]) {
			const unsigned *tokenBytes = (const unsigned *)[deviceToken bytes];
			NSString *hexToken = [NSString stringWithFormat:@"%08x%08x%08x%08x%08x%08x%08x%08x",
			                      ntohl(tokenBytes[0]), ntohl(tokenBytes[1]), ntohl(tokenBytes[2]),
			                      ntohl(tokenBytes[3]), ntohl(tokenBytes[4]), ntohl(tokenBytes[5]),
			                      ntohl(tokenBytes[6]), ntohl(tokenBytes[7])];
			resultStr = hexToken;
		}
		else{
			resultStr = @"";
		}
		result(resultStr);

	}
	else if([@"addAlias" isEqualToString:call.method]) {
		NSDictionary* arguments = (NSDictionary *)call.arguments;
		NSString* name = [arguments valueForKey:@"alias"];
		NSString* type = [arguments valueForKey:@"type"];
		[UMessage addAlias:name type:type response:^(id _Nonnull responseObject, NSError * _Nonnull error) {
		         //NSMutableDictionary* resultDic = [[NSMutableDictionary alloc] init];
		         NSNumber* resultNum = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 //[resultDic setValue:error.description forKey:@"error"];
				 resultNum = [NSNumber numberWithBool:NO];
			 }
		         else{
				 NSLog(@"responseObject:%@",responseObject);
//                if ([responseObject isKindOfClass:[NSDictionary class]]) {
//                    [resultDic addEntriesFromDictionary:responseObject];
//                }
				 resultNum = [NSNumber numberWithBool:YES];
			 }
		         //NSString* resultStr =  jsonStringForPlugin(resultDic);
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultNum);
					});
		 }];

	}
	else if([@"setAlias" isEqualToString:call.method]) {
		NSDictionary* arguments = (NSDictionary *)call.arguments;
		NSString* name = [arguments valueForKey:@"alias"];
		NSString* type = [arguments valueForKey:@"type"];
		[UMessage setAlias:name type:type response:^(id _Nullable responseObject, NSError * _Nullable error) {
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(!error ? @(true): @(false));
					});
		 }];
	}
	else if([@"removeAlias" isEqualToString:call.method]) {
		NSDictionary* arguments = (NSDictionary *)call.arguments;
		NSString* name = [arguments valueForKey:@"alias"];
		NSString* type = [arguments valueForKey:@"type"];
		[UMessage removeAlias:name type:type response:^(id _Nonnull responseObject, NSError * _Nonnull error) {
		         NSNumber* resultNum = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 resultNum = [NSNumber numberWithBool:NO];
			 }
		         else{
				 NSLog(@"responseObject:%@",responseObject);
				 resultNum = [NSNumber numberWithBool:YES];
			 }
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultNum);
					});
		 }];
	}
	else if([@"addTag" isEqualToString:call.method]) {
		NSArray* arguments = (NSArray *)call.arguments;
		[UMessage addTags:arguments response:^(id _Nonnull responseObject, NSInteger remain, NSError * _Nonnull error) {
		         NSNumber* resultNum = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 resultNum = [NSNumber numberWithBool:NO];
			 }
		         else{
				 NSLog(@"responseObject:%@",responseObject);
				 resultNum = [NSNumber numberWithBool:YES];
			 }
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultNum);
					});
		 }];
	}
	else if([@"removeTag" isEqualToString:call.method]) {
		NSArray* arguments = (NSArray *)call.arguments;
		[UMessage deleteTags:arguments response:^(id _Nonnull responseObject, NSInteger remain, NSError * _Nonnull error) {
		         NSNumber* resultNum = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 resultNum = [NSNumber numberWithBool:NO];
			 }
		         else{
				 NSLog(@"responseObject:%@",responseObject);
				 resultNum = [NSNumber numberWithBool:YES];
			 }
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultNum);
					});
		 }];
	}
	else if([@"getTags" isEqualToString:call.method]) {
//        NSArray* arguments = (NSArray *)call.arguments;
		[UMessage getTags:^(NSSet * _Nonnull responseTags, NSInteger remain, NSError * _Nonnull error) {
		         NSArray<NSString*>* resultArr = NULL;
		         if (error) {
				 NSLog(@"error:%@",error);
				 resultArr = [NSArray array];
			 }
		         else{
				 NSLog(@"responseTags:%@",responseTags);
				 NSArray* tempResultArr = [responseTags allObjects];
				 resultArr = [[NSArray alloc] initWithArray:tempResultArr];
			 }
		         dispatch_async(dispatch_get_main_queue(), ^{
						result(resultArr);
					});
		 }];
	}
	else if([@"log_enable" isEqualToString:call.method]) {
		NSLog(@"log_enable is a empty function。see [UMConfigure setLogEnabled:YES]");
	}
	else if([@"enable" isEqualToString:call.method]) {
		NSLog(@"push enable is a empty function");
	}
	else{
		resultCode = NO;
	}

	return resultCode;
}
@end

@interface UmengPushSdkPlugin () <UNUserNotificationCenterDelegate>
@property(nonatomic, strong) FlutterMethodChannel *channel;
@end

@implementation UmengPushSdkPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
	FlutterMethodChannel* channel = [FlutterMethodChannel
	                                 methodChannelWithName:@"u-push"
	                                 binaryMessenger:[registrar messenger]];
	UmengPushSdkPlugin* instance = [[UmengPushSdkPlugin alloc] init];
	instance.channel = channel;
	UNUserNotificationCenter.currentNotificationCenter.delegate = instance;
	[registrar addApplicationDelegate:instance];
	[registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
	BOOL resultCode = [UMengflutterpluginForPush handleMethodCall:call result:result];
	if (resultCode) return;
	result(FlutterMethodNotImplemented);
}

#pragma mark - UIApplicationDelegate
- (void)application:(UIApplication *)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken {
	[UMessage registerDeviceToken:deviceToken];
//    NSString *token = [[deviceToken description] stringByTrimmingCharactersInSet:[NSCharacterSet characterSetWithCharactersInString:@"<>"]];
//    token = [token stringByReplacingOccurrencesOfString:@" " withString:@""];

	NSString *token = [self fetchDeviceToken:deviceToken];
	[self.channel invokeMethod:@"onToken" arguments:token];
}

- (NSString *)fetchDeviceToken:(NSData *)deviceToken {
	NSUInteger len = deviceToken.length;
	if (len == 0) {
		return nil;
	}
	const unsigned char *buffer = deviceToken.bytes;
	NSMutableString *hexString  = [NSMutableString stringWithCapacity:(len * 2)];
	for (int i = 0; i < len; ++i) {
		[hexString appendFormat:@"%02x", buffer[i]];
	}
	return [hexString copy];
}

#pragma mark - UNUserNotificationCenterDelegate
- (void)userNotificationCenter:(UNUserNotificationCenter *)center willPresentNotification:(UNNotification *)notification withCompletionHandler:(void (^)(UNNotificationPresentationOptions))completionHandler {
	NSError *err;
	NSData *jsonData = [NSJSONSerialization dataWithJSONObject:notification.request.content.userInfo options:0 error:&err];
	if (!err) {
		NSString *message = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
		[self.channel invokeMethod:@"onMessage" arguments:message];
	}
	if (completionHandler) {
		completionHandler(UNNotificationPresentationOptionBadge | UNNotificationPresentationOptionSound | UNNotificationPresentationOptionAlert);
	}
}

- (void)userNotificationCenter:(UNUserNotificationCenter *)center didReceiveNotificationResponse:(UNNotificationResponse *)response withCompletionHandler:(void (^)(void))completionHandler {
	NSError *err;
	NSData *jsonData = [NSJSONSerialization dataWithJSONObject:response.notification.request.content.userInfo options:0 error:&err];
	if (!err) {
		NSString *message = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
		[self.channel invokeMethod:@"onMessage" arguments:message];
	}
	if (completionHandler) {
		completionHandler();
	}
}


@end
